aboutsummaryrefslogtreecommitdiff
path: root/spss.server/src/at/gv/egovernment/moa/spss
diff options
context:
space:
mode:
Diffstat (limited to 'spss.server/src/at/gv/egovernment/moa/spss')
-rw-r--r--spss.server/src/at/gv/egovernment/moa/spss/server/iaik/pki/revocation/RevocationProfileImpl.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/spss.server/src/at/gv/egovernment/moa/spss/server/iaik/pki/revocation/RevocationProfileImpl.java b/spss.server/src/at/gv/egovernment/moa/spss/server/iaik/pki/revocation/RevocationProfileImpl.java
index 164ae8a75..d9f9bc679 100644
--- a/spss.server/src/at/gv/egovernment/moa/spss/server/iaik/pki/revocation/RevocationProfileImpl.java
+++ b/spss.server/src/at/gv/egovernment/moa/spss/server/iaik/pki/revocation/RevocationProfileImpl.java
@@ -22,8 +22,8 @@ public class RevocationProfileImpl implements RevocationProfile {
/** The <code>ConfigurationProvider</code> to read the MOA configuration data
* from. */
private ConfigurationProvider config;
- /** The OCSP request hash algorithm. */
- private String oCSPRequestHashAlgorithm;
+ /** The OCSP request hash algorithm. Currently only "SHA" is supported. */
+ private static final String oCSPRequestHashAlgorithm = "SHA";
/**
* Create a new <code>RevocationProfileImpl</code>.
@@ -32,7 +32,8 @@ public class RevocationProfileImpl implements RevocationProfile {
*/
public RevocationProfileImpl(ConfigurationProvider config) {
this.config = config;
- this.oCSPRequestHashAlgorithm = "";
+ // currently only "SHA" is supported
+// this.oCSPRequestHashAlgorithm = "";
}
/**